# limit parallel builds on aarch64
%ifarch aarch64
  %global _smp_ncpus_max 8
%endif

# Wayland EGL support
%bcond_with wayland_egl

%define	Werror_cflags	%nil

%ifarch x86_64
%define buildarch	-DKICAD_BUILD_ARCH_X64:BOOL=ON
%endif

%ifarch %ix86
%define buildarch	-DKICAD_BUILD_ARCH_X86:BOOL=ON
%endif

%ifarch %arm
%define buildarch	-DKICAD_BUILD_ARCH_ARM:BOOL=ON
%endif

%ifarch %arm64
%define buildarch	-DKICAD_BUILD_ARCH_ARM64:BOOL=ON
%endif

Name:		kicad
Summary:	An open source program for the creation of electronic schematic diagrams
Epoch:		1
Version:	8.0.8
Release:	%mkrel 1
License:	GPLv3+
Group:		Sciences/Computer science
Url:		https://www.kicad.org/
Source0:	https://gitlab.com/kicad/code/kicad/-/archive/%{version}/%{name}-%{version}.tar.bz2
# upstream disable the "find_package(wxPython)" on ARM64, why???
Patch0:		kicad-find-wxPython-also-on-aarch64.patch
# Patch1:		0001-Fix-compilation-with-Boost-1.86.patch
BuildRequires:	cmake
BuildRequires:	chrpath
BuildRequires:	doxygen
BuildRequires:	ninja
BuildRequires:	wxgtk-devel
BuildRequires:	mesa-common-devel
BuildRequires:	imagemagick
BuildRequires:	boost-devel
BuildRequires:	glm-devel
BuildRequires:	opencascade-devel
BuildRequires:	pkgconfig(ngspice)
BuildRequires:	EGL-devel
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(odbc)
BuildRequires:	pkgconfig(openssl) >= 1.1
BuildRequires:	libgomp-devel
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libgit2)
BuildRequires:	pkgconfig(libsecret-1)
# python scripting
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-wxpython4
BuildRequires:	swig

BuildRequires:	desktop-file-utils

Requires:	%{name}-doc >= 1:%{version}
Requires:	%{name}-symbols >= 1:%{version}
Recommends:	%{name}-packages3d >= 1:%{version}
Requires:	%{name}-templates >= 1:%{version}
Requires:	%{name}-footprints >= 1:%{version}
Requires:	python3-wxpython4

%description
Kicad is an open source (GPL) program for the creation of electronic
schematic diagrams and printed circuit board artwork.

Kicad is a set of four programs and a project manager:

* Eeschema:     Schematic entry.
* Pcbnew:       Board editor.
* Gerbview:     GERBER viewer (photoplotter documents).
* Cvpcb:        footprint selector for components used in the circuit design.
* Kicad:        project manager.

%prep
%autosetup -p1

%build
export LC_ALL=C.UTF-8

# Building kicad
%cmake -GNinja \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DCMAKE_BUILD_TYPE=Release \
	-DKICAD_BUILD_QA_TESTS=OFF \
	%{?buildarch} \
	-DKICAD_BUILD_I18N=ON \
	-DKICAD_I18N_UNIX_STRICT_PATH:BOOL=ON \
%if %{with wayland_egl}
	-DKICAD_USE_EGL=ON \
	-DKICAD_USE_BUNDLED_GLEW=OFF \
%endif
	-DKICAD_SCRIPTING_WXPYTHON=ON \
	-DPYTHON_SITE_PACKAGE_PATH=%{python3_sitearch} \
	-DKICAD_VERSION_EXTRA=%{release}
%cmake_build

%install
%cmake_install

%find_lang %{name}

# drop RPATH
chrpath -d %{buildroot}%{python3_sitearch}/_pcbnew.so

# create desktop file
for i in %{buildroot}%{_datadir}/applications/*.desktop; do
desktop-file-edit \
	--remove-category='Scientific' \
	--add-category='Science;Electronics;Education' \
	$i
done

# remove unwanted devel files
rm -r %{buildroot}%{_libdir}/{libkicommon.so,libkigal.so,libkicad_3dsg.so}

%files -f %{name}.lang
%license LICENSE*
%doc AUTHORS.txt
%{_bindir}/*
%{_libdir}/libkicad_3dsg.so.*
%{_libdir}/libkicommon.so.*
%{_libdir}/libkigal.so.*
%{_iconsdir}/hicolor/*/{apps,mimetypes}/*.{png,svg}
%{_datadir}/applications/org.kicad.*.desktop
%{_datadir}/mime/packages/kicad-*.xml
%{_metainfodir}/org.kicad.kicad.metainfo.xml
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/demos/
%{_datadir}/%{name}/plugins/
%{_datadir}/%{name}/resources/
%{_datadir}/%{name}/schemas/
%{_datadir}/%{name}/scripting/
%{_datadir}/%{name}/template/
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/plugins/

%{python3_sitearch}/_pcbnew.so
%{python3_sitearch}/pcbnew.*
%{python3_sitearch}/__pycache__/*


%changelog
* Tue Jan 28 2025 papoteur <papoteur> 1:8.0.8-1.mga10
+ Revision: 2143176
- new version 8.0.8

* Tue Oct 01 2024 daviddavid <daviddavid> 1:8.0.5-1.mga10
+ Revision: 2102337
- new version: 8.0.5

* Sun May 12 2024 daviddavid <daviddavid> 1:8.0.2-1.mga10
+ Revision: 2063847
- new version: 8.0.2 (support for occt >= 7.8)
- rebuild for new opencascade 7.8.1

* Sat Mar 16 2024 daviddavid <daviddavid> 1:8.0.1-1.1.mga10
+ Revision: 2050036
- new version: 8.0.1

* Thu Dec 28 2023 daviddavid <daviddavid> 1:7.0.8-2.mga10
+ Revision: 2023154
- rebuild for py3.12

* Sat Oct 28 2023 daviddavid <daviddavid> 1:7.0.8-1.mga10
+ Revision: 2002386
- new version: 7.0.8

* Thu Mar 16 2023 ghibo <ghibo> 1:7.0.1-1.mga9
+ Revision: 1949471
- Update to release 7.0.1

* Tue Feb 21 2023 ghibo <ghibo> 1:7.0.0-1.mga9
+ Revision: 1944550
- Update to release 7.0.0.
- Rework Patch1.
- Add odbc-devel to BuildRequires.
- Remove %%py3_shebang_fix as files were removed.
- Fix files list.

* Sat Feb 11 2023 ghibo <ghibo> 1:6.0.11-1.mga9
+ Revision: 1940686
- Update to release 6.0.11

* Fri Jan 06 2023 ghibo <ghibo> 1:6.0.10-1.mga9
+ Revision: 1930599
- Update to release 6.0.10

* Thu Nov 03 2022 ghibo <ghibo> 1:6.0.9-1.mga9
+ Revision: 1902138
- Rebuild against newer opencascade 7.6.x.
- Update to release 6.0.9.

* Mon Oct 03 2022 neoclust <neoclust> 1:6.0.8-1.mga9
+ Revision: 1894321
- New version 6.0.8

* Fri Jul 29 2022 wally <wally> 1:6.0.7-1.mga9
+ Revision: 1872877
- new version 6.0.7

* Wed Jul 27 2022 wally <wally> 1:6.0.6-1.mga9
+ Revision: 1872522
- new version 6.0.6

* Fri Jul 15 2022 wally <wally> 1:6.0.5-3.mga9
+ Revision: 1868992
- rebuild for wxgtk 3.2.0

* Sun Jun 12 2022 wally <wally> 1:6.0.5-2.mga9
+ Revision: 1864100
- rebuild for wxgtk 3.1.7

* Thu May 12 2022 wally <wally> 1:6.0.5-1.mga9
+ Revision: 1857794
- new version 6.0.5

* Fri Apr 15 2022 wally <wally> 1:6.0.4-1.mga9
+ Revision: 1850225
- new version 6.0.4
- rebuild for wxgtk 3.1.6
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 1:6.0.1-2.mga9
+ Revision: 1787418
- rebuild for python-3.10

* Sat Jan 29 2022 wally <wally> 1:6.0.1-1.mga9
+ Revision: 1770368
- new version 6.0.1

* Sat Jan 15 2022 wally <wally> 1:6.0.0-5.mga9
+ Revision: 1768506
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Tue Jan 04 2022 wally <wally> 1:6.0.0-4.mga9
+ Revision: 1766826
- build without EGL support (our GLEW doesn't have EGL support ATM)

* Tue Jan 04 2022 wally <wally> 1:6.0.0-3.mga9
+ Revision: 1766805
- split out into a separate src rpm
  - kicad-templates
- kicad symbols
- kicad-footprints
- kicad-doc
- kicad-packages3d

* Mon Jan 03 2022 wally <wally> 1:6.0.0-2.mga9
+ Revision: 1766404
- build KiCad with EGL backend support for Wayland

* Mon Jan 03 2022 wally <wally> 1:6.0.0-1.mga9
+ Revision: 1766341
- new version 6.0.0
- add symbols, 3dmodels, templates and footprints subpackages
- drop separate library package
- drop separate i18n package
- build using Ninja isntead of make
- update URL

* Sun Jan 02 2022 wally <wally> 1:5.1.10-3.mga9
+ Revision: 1766143
- fix RPATH
- install python modules to arch specific location
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error
- rebuild for openssl 3.0.0

* Wed Apr 28 2021 daviddavid <daviddavid> 1:5.1.10-1.mga9
+ Revision: 1720194
- new version: 5.1.10

* Mon Mar 22 2021 daviddavid <daviddavid> 1:5.1.9-3.mga9
+ Revision: 1707791
- rebuild for python 3.9

* Mon Jan 04 2021 daviddavid <daviddavid> 1:5.1.9-2.mga8
+ Revision: 1668621
- switch to wxgtk 3.1

* Wed Dec 23 2020 daviddavid <daviddavid> 1:5.1.9-1.mga8
+ Revision: 1663055
- new version: 5.1.9

* Wed Dec 02 2020 luigiwalser <luigiwalser> 1:5.1.8-2.mga8
+ Revision: 1651354
- rebuild for glew

* Wed Nov 18 2020 daviddavid <daviddavid> 1:5.1.8-1.mga8
+ Revision: 1647001
- new version: 5.1.8

* Wed Nov 04 2020 daviddavid <daviddavid> 1:5.1.7-2.mga8
+ Revision: 1642600
- switch to opencascade (OCC)

* Sun Sep 27 2020 daviddavid <daviddavid> 1:5.1.7-1.mga8
+ Revision: 1630813
- new version: 5.1.7

* Thu May 14 2020 daviddavid <daviddavid> 1:5.1.6-1.mga8
+ Revision: 1583603
- new version: 5.1.6

* Tue Feb 18 2020 umeabot <umeabot> 1:5.1.5-2.mga8
+ Revision: 1538320
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Tue Nov 19 2019 daviddavid <daviddavid> 1:5.1.5-1.mga8
+ Revision: 1461735
- new version: 5.1.5

* Sun Sep 15 2019 daviddavid <daviddavid> 1:5.1.4-2.mga8
+ Revision: 1441781
- rebuild for python3.8

* Mon Aug 19 2019 daviddavid <daviddavid> 1:5.1.4-1.mga8
+ Revision: 1430310
- new version: 5.1.4

* Mon Jul 29 2019 daviddavid <daviddavid> 1:5.1.3-1.mga8
+ Revision: 1425109
- new version: 5.1.3

* Sat Jul 20 2019 wally <wally> 1:5.1.2-3.mga8
+ Revision: 1423067
- rebuild with gtk3 enabled wxgtk3.0

* Mon May 06 2019 daviddavid <daviddavid> 1:5.1.2-2.mga7
+ Revision: 1396509
- switch to python3-wxpython4

* Tue Apr 23 2019 daviddavid <daviddavid> 1:5.1.2-1.mga7
+ Revision: 1394879
- new version: 5.1.2

* Wed Apr 17 2019 daviddavid <daviddavid> 1:5.1.1-1.mga7
+ Revision: 1392103
- new version: 5.1.1

* Mon Mar 18 2019 daviddavid <daviddavid> 1:5.1.0-1.mga7
+ Revision: 1378703
- new version: 5.1.0

* Fri Mar 01 2019 daviddavid <daviddavid> 1:5.0.2-2.mga7
+ Revision: 1370620
- remove unwanted devel files

* Wed Feb 20 2019 zezinho <zezinho> 1:5.0.2-1.mga7
+ Revision: 1368861
- new version 5

* Tue Oct 16 2018 wally <wally> 1:4.0.6-11.mga7
+ Revision: 1321049
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 1:4.0.6-10.mga7
+ Revision: 1298541
- Mageia 7 Mass Rebuild

* Wed Jul 18 2018 wally <wally> 1:4.0.6-9.mga7
+ Revision: 1244224
- fix build with CMake >= 3.11

* Mon Dec 25 2017 wally <wally> 1:4.0.6-8.mga7
+ Revision: 1184677
- rebuild for new boost

* Sun Dec 03 2017 daviddavid <daviddavid> 1:4.0.6-7.mga7
+ Revision: 1180797
- rebuild for new glew 2.1.0

* Tue Nov 21 2017 tv <tv> 1:4.0.6-6.mga7
+ Revision: 1178114
- rebuild for boost 1.65

* Tue Sep 26 2017 tv <tv> 1:4.0.6-5.mga7
+ Revision: 1159890
- fix build with newer boost
- rebuild with latest boost

* Tue Sep 05 2017 cjw <cjw> 1:4.0.6-4.mga7
+ Revision: 1151485
- fix debug packages
+ daviddavid <daviddavid>
- rebuild for new glew 2.0.0

* Sat Jun 03 2017 akien <akien> 1:4.0.6-3.mga6
+ Revision: 1106098
- Rebuild for wxgtk 3.0.3.1

* Mon May 29 2017 neoclust <neoclust> 1:4.0.6-2.mga6
+ Revision: 1105516
- Rebuild with fixed python pip
+ akien <akien>
- New version 4.0.6 packaged by Juergen Harms (mga#9353)
  o correct Source0 specification: /.../%%{name}/4.0/%%{version}/+download/... to .../%%{name}-%%{version}/+download/...
  o add missing "Requires: wxPython"
  o add missing "BuildRequires: curl-devel"
  o correct "BuildRequires: BuildRequires Perl(Unicode:GCString)" to "BuildRequires: perl(Unicode::LineBreak)"
  o verify that the patches used in Fedora kicad 4.0.6 are not needed in Mageia environment
  o review and update list of kicad libraries (xxx.pretty) to include, based on upstream fp-lib-table.for-pretty

* Tue Sep 27 2016 daviddavid <daviddavid> 1:4.0.4-1.mga6
+ Revision: 1057110
- new version: 4.0.4
- remove merged upstream patch
- fix some ownership dir

* Thu Aug 18 2016 luigiwalser <luigiwalser> 1:4.0.1-6.mga6
+ Revision: 1046898
- rediff patch from opensuse to fix build with swig 3.0.10

* Thu Jun 02 2016 daviddavid <daviddavid> 1:4.0.1-5.mga6
+ Revision: 1019816
- rebuild for wxgtk3.0 built with GTK2

* Wed Mar 02 2016 umeabot <umeabot> 1:4.0.1-4.mga6
+ Revision: 983547
- Rebuild for openssl

* Sat Dec 26 2015 daviddavid <daviddavid> 1:4.0.1-3.mga6
+ Revision: 915357
- rebuild for new boost 1.60.0

* Mon Dec 21 2015 ycantin <ycantin> 1:4.0.1-2.mga6
+ Revision: 913195
- bundle footprints

* Sun Dec 20 2015 ycantin <ycantin> 1:4.0.1-1.mga6
+ Revision: 912497
- new version 4.0.1

* Sun Dec 06 2015 ycantin <ycantin> 1:4.0.0-1.mga6
+ Revision: 908586
- fix build
- fix release versioning
- fix licensing
- add Epoch to deal with version numbering change
- new version 4.0.0
- merge i18n packages
- enable python scripting
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 20130725.bzr4024-5.mga5
+ Revision: 726643
- rebuild for missing pythoneggs deps
- s/uggests:/Recommends:/
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Wed Feb 05 2014 stormi <stormi> 20130725.bzr4024-3.mga5
+ Revision: 583863
- add missing icon for eeschema (mga#8425), thanks to AlexL

* Mon Oct 21 2013 umeabot <umeabot> 20130725.bzr4024-2.mga4
+ Revision: 537828
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 akien <akien> 20130725.bzr4024-1.mga4
+ Revision: 487797
- Reverting erroneous libpath introduced in r487685
- Update to current stable release (r4024 for the program) using update.sh script
- Removed trailing spaces and fixed inconsistent use of spaces and tabs

* Wed Jul 10 2013 fwang <fwang> 20111221.bzr3253-4.mga4
+ Revision: 452341
- rebuild for new boost

* Sat Jan 12 2013 umeabot <umeabot> 20111221.bzr3253-3.mga3
+ Revision: 356169
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 05 2012 juancho <juancho> 20111221.bzr3253-2.mga3
+ Revision: 326831
- Added upstream patch to fix boost build failure.

* Thu Jan 19 2012 fwang <fwang> 20111221.bzr3253-1.mga2
+ Revision: 198405
- build with wxgtku
+ mcb30 <mcb30>
- Remove requirement for specific versions of library and doc packages
- Update to latest stable version (using auto-update script)
  Fix BuildRequires to work on Mageia 1 as well as Cauldron
- Add auto-update script to rebuild tarballs from bzr checkouts

* Sat Dec 17 2011 wally <wally> 20110720.bzr3052-2.mga2
+ Revision: 182876
- fix build
- wxGTK-devel BR was renamed to wxgtk-devel
+ mcb30 <mcb30>
- Add Requires: locales-XX for each locale subpackage
- Provide dummy "en" locale package to minimise user confusion

* Sat Nov 12 2011 shlomif <shlomif> 20110720.bzr3052-1.mga2
+ Revision: 166922
- software is an uncountable noun
- software is an uncountable noun
+ mcb30 <mcb30>
- Removed old sources (not automatically removed via "mgarepo sync")
- Update to latest stable version
- Remove specfile cruft
- Remove specfile cruft
- imported package kicad


* Fri Nov 11 2011 Michael Brown <mbrown@fensystems.co.uk> 20110525.bzr3009-7
- Remove references to %%mdkversion

* Sun Jun 05 2011 Alexandre Lissy <alissy@mandriva.com> 20110525.bzr3009-6mdv2011.0
+ Revision: 682787
- Only one %%mkrel
- Split kicad-locales into several package, each providing kicad-locales-X and kicad-locale
- Adding Suggests from kicad to kicad-locale
- Unifying versions number
- Changing requires
- Adding missing License
- Release bump, package eaten by build system :(
- Updating release ...
- Fix bad version number for kicad-locales

* Fri Jun 03 2011 Alexandre Lissy <alissy@mandriva.com> 20110525.bzr3009-1
+ Revision: 682668
- Fixing typo in versions definitions
- Unification of all kicad sources packages
- Updating kicad, kicad-doc and kicad-library to latest (stable) bazaar revsion
- Adding new kicad-locales package
- Setting noarch for kicad-doc, kicad-library and kicad-locales
- Updating Kicad to latest release

* Mon Dec 06 2010 Oden Eriksson <oeriksson@mandriva.com> 20100314-2mdv2011.0
+ Revision: 612604
- the mass rebuild of 2010.1 packages

* Wed Apr 14 2010 Funda Wang <fwang@mandriva.org> 20100314-1mdv2010.1
+ Revision: 534645
- clean old switches

  + trem <trem@mandriva.org>
    - remove use of iconscaldir
    - update to 20100314

* Wed Jul 15 2009 trem <trem@mandriva.org> 20090216-1mdv2010.0
+ Revision: 396494
- update to 2009-02-16
- add lot of patches to fix printf format

  + Oden Eriksson <oeriksson@mandriva.com>
    - lowercase ImageMagick

* Tue Aug 26 2008 trem <trem@mandriva.org> 20080715-4mdv2009.0
+ Revision: 276407
- new mdvrelease
- replace kicad-20080715-fix-desktop.patch by fix_desktop.patch

* Tue Aug 26 2008 Funda Wang <fwang@mandriva.org> 20080715-3mdv2009.0
+ Revision: 276396
- drop our own desktop file

* Tue Aug 26 2008 Funda Wang <fwang@mandriva.org> 20080715-2mdv2009.0
+ Revision: 276135
- fix license
- fix desktop file

* Thu Aug 21 2008 trem <trem@mandriva.org> 20080715-1mdv2009.0
+ Revision: 274944
- update to 20080715

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - rebuild
    - drop old menu
    - kill re-definition of %%buildroot on Pixel's request
    - import kicad

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


* Tue Aug  1 2006 Couriousous <couriousous@mandriva.org> 20060626-1mdv2007.0
- XDG
- 20060626

* Tue Apr 18 2006 Nicolas Lécureuil <neoclust@mandriva.org> 20060321-2mdk
- Fix BuildRequires
- use mkrel

* Mon Apr 17 2006 Couriousous <couriousous@mandriva.org> 20060321-1mdk
- 20060321

* Fri Sep  9 2005 Couriousous <couriousous@mandriva.org> 20050906-1mdk
- 20050906

* Tue Jul 26 2005 Couriousous <couriousous@mandriva.org> 20050725-1mdk
- 20050725
- Kicad is now FHS complient

* Sun Jul 17 2005 Couriousous <couriousous@mandriva.org> 20050704-1mdk
- First Mandriva release
- Patch for gcc4
- Patch for amd64

